==> vtigercrm7.1.0rc.tar.gz: vtigercrm/pkg/vtiger/translations/TurkishLanguagePack_tr_tr/modules/Home.php <==
<?php
/*+**********************************************************************************
 * The contents of this file are subject to the vtiger CRM Public License Version 1.0
 * ("License"); You may not use this file except in compliance with the License
 * The Original Code is:  vtiger CRM Open Source
 * The Initial Developer of the Original Code is vtiger.
 * Portions created by vtiger are Copyright (C) vtiger.
 * All Rights Reserved.
 ************************************************************************************/
$languageStrings = array(
	'ALVT'                         => 'Önemli Müşteriler'        , 
	'PLVT'                         => 'Önemli Fırsatlar'          , 
	'QLTQ'                         => 'Önemli Teklifler'           , 
	'CVLVT'                        => 'Kilit Ölçümler'           , 
	'HLT'                          => 'Top Support Tickets'         , 
	'GRT'                          => 'Grup Dağıtımım'          , 
	'OLTSO'                        => 'Önemli Satış Siparişleri', 
	'ILTI'                         => 'Önemli Faturalar'           , 
	'HDB'                          => 'Ana Sayfa Grafikleri'        , 
	'OLTPO'                        => 'Önemli Satınalma Siparişleri', 
	'LTFAQ'                        => 'Yakın SSS'                  , 
	'UA'                           => 'Gelecek İşler'             , 
	'PA'                           => 'Bekleyen İşler'            , 
        'Home'                         => 'Dashboard'                 ,

  'LBL_SAVE_ORDER' => 'Kaydet Emri',
  'LBL_ADD_NEW_DASHBOARD' => 'Yeni bir pano Ekle ',
	'LBL_MAX_CHARACTERS_ALLOWED_DASHBOARD' => 'Maksimum 30 karakter pano adı için izin verilir.',
);

==> vtigercrm8.4.0.tar.gz: vtigercrm/pkg/vtiger/translations/TurkishLanguagePack_tr_tr/modules/Home.php <==
<?php
/*+**********************************************************************************
 * The contents of this file are subject to the vtiger CRM Public License Version 1.0
 * ("License"); You may not use this file except in compliance with the License
 * The Original Code is:  vtiger CRM Open Source
 * The Initial Developer of the Original Code is vtiger.
 * Portions created by vtiger are Copyright (C) vtiger.
 * All Rights Reserved.
 ************************************************************************************/
$languageStrings = array(
	'ALVT'                         => 'Önemli Müşteriler'        , 
	'PLVT'                         => 'Önemli Fırsatlar'          , 
	'QLTQ'                         => 'Önemli Teklifler'           , 
	'CVLVT'                        => 'Kilit Ölçümler'           , 
	'HLT'                          => 'Top Support Tickets'         , 
	'GRT'                          => 'Grup Dağıtımım'          , 
	'OLTSO'                        => 'Önemli Satış Siparişleri', 
	'ILTI'                         => 'Önemli Faturalar'           , 
	'HDB'                          => 'Ana Sayfa Grafikleri'        , 
	'OLTPO'                        => 'Önemli Satınalma Siparişleri', 
	'LTFAQ'                        => 'Yakın SSS'                  , 
	'UA'                           => 'Gelecek İşler'             , 
	'PA'                           => 'Bekleyen İşler'            , 
        'Home'                         => 'Dashboard'                 ,

  'LBL_SAVE_ORDER' => 'Kaydet Emri',
  'LBL_ADD_NEW_DASHBOARD' => 'Yeni bir pano Ekle ',
	'LBL_MAX_CHARACTERS_ALLOWED_DASHBOARD' => 'Maksimum 30 karakter pano adı için izin verilir.',
);

$jsLanguageStrings = array(
	'JS_TAB_NAME_SHOULD_NOT_BE_EMPTY' => 'Pano adı boş olamaz olamaz',
	'JS_NO_DATA_AVAILABLE' => 'veri yok',
);
